# Config file for the libemos package
# Defines the following variables:
#
#  LIBEMOS_INCLUDE_DIRS   - include directories
#  LIBEMOS_DEFINITIONS    - preprocessor definitions
#  LIBEMOS_LIBRARIES      - libraries to link against
#  LIBEMOS_FEATURES       - list of enabled features
#  LIBEMOS_VERSION        - version of the package
#  LIBEMOS_GIT_SHA1       - Git revision of the package
#  LIBEMOS_GIT_SHA1_SHORT - short Git revision of the package
#
# Also defines libemos third-party library dependencies:
#  LIBEMOS_TPLS             - package names of  third-party library dependencies
#  LIBEMOS_TPL_INCLUDE_DIRS - include directories
#  LIBEMOS_TPL_DEFINITIONS  - preprocessor definitions
#  LIBEMOS_TPL_LIBRARIES    - libraries to link against

### compute paths

get_filename_component(LIBEMOS_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

set( LIBEMOS_SELF_INCLUDE_DIRS "${LIBEMOS_CMAKE_DIR}/../../../include" )
set( LIBEMOS_SELF_DEFINITIONS  "gfortran;REAL_8;REAL_BIGGER_THAN_INTEGER;POINTER_64;_LARGEFILE64_SOURCE;_FILE_OFFSET_BITS=64;EMOS_LITTLE_ENDIAN;INTEGER_IS_INT" )
set( LIBEMOS_SELF_LIBRARIES    "emos" )

set( LIBEMOS_TPLS              "FFTW;eccodes" )
set( LIBEMOS_TPL_INCLUDE_DIRS  "" )
set( LIBEMOS_TPL_DEFINITIONS   "" )
set( LIBEMOS_TPL_LIBRARIES     "/usr/local/lib/libfftw3.so" )

set( LIBEMOS_VERSION           "4.5.9" )
set( LIBEMOS_GIT_SHA1          "" )
set( LIBEMOS_GIT_SHA1_SHORT    "" )

### export include paths as absolute paths

set( LIBEMOS_INCLUDE_DIRS "" )
foreach( path ${LIBEMOS_SELF_INCLUDE_DIRS} )
  get_filename_component( abspath ${path} ABSOLUTE )
  list( APPEND LIBEMOS_INCLUDE_DIRS ${abspath} )
endforeach()
list( APPEND LIBEMOS_INCLUDE_DIRS ${LIBEMOS_TPL_INCLUDE_DIRS} )

### export definitions

set( LIBEMOS_DEFINITIONS      ${LIBEMOS_SELF_DEFINITIONS} ${LIBEMOS_TPL_DEFINITIONS} )

### export list of all libraries

set( LIBEMOS_LIBRARIES        ${LIBEMOS_SELF_LIBRARIES}   ${LIBEMOS_TPL_LIBRARIES}   )

### export the features provided by the package

set( LIBEMOS_FEATURES    "TESTS;INSTALL_TABLES;INSTALL_TOOLS;FORTRAN90;SINGLE_PRECISION;GRIBEX_ABORT;REQUIRE_FFTW;FFTW;LIBEMOS_BUFRDC;LIBEMOS_INTERPOLATION;LIBEMOS_GRIBEX;ECCODES" )
foreach( _f ${LIBEMOS_FEATURES} )
  set( LIBEMOS_HAVE_${_f} 1 )
endforeach()

# Has this configuration been exported from a build tree?
set( LIBEMOS_IS_BUILD_DIR_EXPORT OFF )

if( EXISTS ${LIBEMOS_CMAKE_DIR}/libemos-import.cmake )
  set( LIBEMOS_IMPORT_FILE "${LIBEMOS_CMAKE_DIR}/libemos-import.cmake" )
  include( ${LIBEMOS_IMPORT_FILE} )
endif()

# here goes the imports of the TPL's

include( ${CMAKE_CURRENT_LIST_FILE}.tpls OPTIONAL )

# insert definitions for IMPORTED targets

if( NOT libemos_BINARY_DIR )

  if( LIBEMOS_IS_BUILD_DIR_EXPORT )
    include( "/construction/misc/libemos/.build/libemos-targets.cmake" OPTIONAL )
  else()
    include( "${LIBEMOS_CMAKE_DIR}/libemos-targets.cmake" OPTIONAL )
  endif()

endif()

# publish this file as imported

set( LIBEMOS_IMPORT_FILE ${CMAKE_CURRENT_LIST_FILE} )
mark_as_advanced( LIBEMOS_IMPORT_FILE )

# set libemos_BASE_DIR for final installations or build directories

if( NOT libemos )
  if( LIBEMOS_IS_BUILD_DIR_EXPORT )
    set( libemos_BASE_DIR /construction/misc/libemos/.build )
  else()
    get_filename_component( abspath ${CMAKE_CURRENT_LIST_DIR}/../../.. ABSOLUTE )
    set( libemos_BASE_DIR ${abspath} )
  endif()
endif()
